/****************************************************************************
**
** DCOP Stub Definition created by dcopidl2cpp from kpl.kidl
**
** WARNING! All changes made in this file will be lost!
**
*****************************************************************************/

#ifndef __KPL_STUB__
#define __KPL_STUB__

#include <dcopstub.h>
#include <kurl.h>
#include <kmainwindow.h>
#include <dcopobject.h>
#include <qstringlist.h>
#include <qptrlist.h>
#include <config.h>


class Kpl_stub : virtual public DCOPStub
{
public:
    Kpl_stub( const QCString& app, const QCString& id );
    Kpl_stub( DCOPClient* client, const QCString& app, const QCString& id );
    explicit Kpl_stub( const DCOPRef& ref );
    virtual void newPlot();
    virtual int openPlot( const QString& url );
    virtual int openData( const QString& url );
    virtual void doPlot();
    virtual int savePlot( const QString& url );
    virtual int savePS( const QString& url, int orientation );
    virtual int printPlot( const QString& printerName, const QString& fileName, int orientation, int numCopies );
    virtual void setAutoplotOption( int setting );
    virtual void setAddFilesOption( int setting );
    virtual void setPathOption( int setting );
    virtual void setBoundingBoxOption( int setting );
    virtual void setPageFormat( double w, double h );
    virtual void setColors( const QString& colFrame, const QString& colGrid, const QString& colData );
    virtual void setOutputFormat( const QString& pres, int prec );
    virtual void setAutoplot( double x0, double w, double y0, double h, int gridmode, const QString& sx, const QString& sy, const QString& sh, int pathHeading, int ix, int iy, int ie, int logx, int logy, int errbars, int symb, int autoNorm, int autoFit );
    virtual void setAutofit( const QString& path, const QString& name, int nonLin, int errCol, const QString& errModPath, const QString& errModName, int itMax, double tol, int symb, const QString& color, int showDlg, int savePar, int follow );
    virtual int loadAutofitPar( const QString& url );
    virtual int setAutofitPar( int iPar, double value );
    virtual int enableFitPar( int iPar, int fit );
    virtual int loadErrModPar( const QString& url, int iArr );
    virtual int setErrModPar( int iPar, double value, int iArr );
    virtual int deleteItem( int iItem );
    virtual int moveItem( int is, int id );
    virtual int activateItem( int iItem, int active );
    virtual void newFrameItem( double x0, double w, double y0, double h, double xmin, double xmax, double ymin, double ymax, int logx, int logy, int ndigx, int ndigy, const QString& colFrame, const QString& colGrid, double xtic, double ytic, int mticx, int mticy, int gridmode, int iex, int iey, const QString& sx, const QString& sy, const QString& sh, double relSize, int active );
    virtual void newAutoFrameItem();
    virtual int newArrayItem( const QString& path, int ix, int iy, int ie, int istart, int n, int errbars, int symb, const QString& color, double fx, double fy, int active );
    virtual int newFunItem( const QString& path, const QString& name, double xmin, double xmax, double dx, int symb, const QString& color, double fx, double fy, int active );
    virtual int newParFunItem( const QString& pathx, const QString& namex, const QString& pathy, const QString& namey, double tmin, double tmax, double dt, int symb, const QString& color, double fx, double fy, int active );
    virtual void newSplineItem( int deriv, double low, double xmin, double xmax, double dx, int symb, const QString& color, double relSize, double fx, double fy, int active );
    virtual int newArray3DItem( double x0, double w, double y0, double h, double xmin, double xmax, double ymin, double ymax, double zmin, double zmax, int logx, int logy, int logz, int ndigx, int ndigy, int ndigz, const QString& colFrame, const QString& colGrid, const QString& colData, double xtic, double ytic, double ztic, int mticx, int mticy, int mticz, int frame, int gridmode, int gridmode3D, double xBox, double yBox, double zBox, double xRef, double yRef, double phi, double theta, int iex, int iey, int iez, const QString& sx, const QString& sy, const QString& sz, const QString& sh, double relSize, const QString& path, int ix, int iy, int iz, int ie, int istart, int n, int errbars, double smf, double dx, double dz, double fx, double fy, double fz, int active );
    virtual int newFun3DItem( double x0, double w, double y0, double h, double xmin, double xmax, double ymin, double ymax, double zmin, double zmax, int logx, int logy, int logz, int ndigx, int ndigy, int ndigz, const QString& colFrame, const QString& colGrid, const QString& colData, double xtic, double ytic, double ztic, int mticx, int mticy, int mticz, int frame, int gridmode, int gridmode3D, double xBox, double yBox, double zBox, double xRef, double yRef, double phi, double theta, int iex, int iey, int iez, const QString& sx, const QString& sy, const QString& sz, const QString& sh, double relSize, const QString& path, const QString& name, double dx, double dz, double fx, double fy, double fz, int active );
    virtual void newImageItem( const QString& path, double x, double y, double fx, double fy, int active );
    virtual void newLegendItem( int symb, const QString& colSymb, double x, double y, const QString& text, const QString& colText, double xoff, double yoff, double relSize, int active );
    virtual void newTextItem( const QString& text, const QString& color, int align, double x, double y, double dir, double relSize, int active );
    virtual void newLineItem( int symb, const QString& color, double x, double y, double dir, double len, double relSize, int active );
    virtual void newArrowItem( const QString& color, double x, double y, double dir, double len, double relSize, int active );
    virtual void newArcItem( const QString& color, double x, double y, double w, double h, double a, double alen, double relSize, double ang, int active );
    virtual void newRectangleItem( const QString& color, double x, double y, double w, double h, double relSize, int fillStyle, int active );
    virtual void newEllipseItem( const QString& color, double x, double y, double w, double h, double relSize, int fillStyle, int active );
    virtual void newScaleBarItem( const QString& str, const QString& color, double x, double y, double len, double relSize, int orientation, int active );
    virtual int autoScaleFrame( int iItem, int autoNorm );
    virtual int loadPar( const QString& url, int iItem, int yFun );
    virtual int setPar( int iItem, int iPar, double value, int yFun );
    virtual int setArrayRange( int iItem, int iStart, int n );
    virtual int addFitItems( int erase, int iArr, int iFun, int errCol, const QString& errModPath, const QString& errModName );
    virtual int fit( int nonLin, int savePar, int follow );
    virtual int splineFit( int iArr, int iSpl, int deg, double smf, double xmin, double xmax, int errCol, const QString& errModPath, const QString& errModName );
    virtual double chiSquare();
    virtual int saveFitPar( const QString& url );
    virtual int exportValues( const QString& url, int iItem );
protected:
    Kpl_stub() : DCOPStub( never_use ) {}
};


#endif
